// $Id: SSLIOP_OpenSSL_st_T.cpp 71526 2006-03-14 06:14:35Z jtc $

#ifndef TAO_SSLIOP_OPENSSL_ST_T_CPP
#define TAO_SSLIOP_OPENSSL_ST_T_CPP

#include "orbsvcs/SSLIOP/SSLIOP_OpenSSL_st_T.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */


#if !defined (__ACE_INLINE__)
#include "orbsvcs/SSLIOP/SSLIOP_OpenSSL_st_T.inl"
#endif  /* !__ACE_INLINE__ */

#endif  /* TAO_SSLIOP_OPENSSL_ST_T_CPP */
